#!/usr/bin/env python
#coding:utf-8
import sys
reload(sys)
sys.setdefaultencoding('utf-8')
import urllib
import requests 
import urllib2
import sys
import bz2
from os.path import join
HOST = '42qu.cc'
HOST_HTTP = 'http://%s'%HOST
API_URL = '%s/:api/txt/'%HOST_HTTP

def help():
    print """
1.Paste file to 42qucc
  hi@Mars ~$ 42cc < foo.txt  
  http://42qu.cc/xa47qt471
2.Custom url 
  hi@Mars ~$ 42qucc hi < foo.txt
  http://42qu.cc/hi
3.Save web page to local file
  hi@Mars ~$ 42cc  http://42qu.cc/xa47qt471  >  foo.txt
    """

def post(url=''):
    data = ''.join(sys.stdin.readlines())
    files = {'file': ('txt', bz2.compress(data) )}
    r = requests.post(API_URL+url, files=files, timeout=3)
    print HOST_HTTP+"/"+r.text

def main():
    argv = sys.argv
    url = ''
    if len(argv) > 1:
        if len(argv) > 2:
            help()
            return
        url = argv[1]
        if url.startswith(HOST_HTTP):
            url = url[len(HOST_HTTP)+1:] 
            r = requests.get(API_URL+url, timeout=3) 
            print r.text
            return
        else:
            url = argv[1].lstrip("/")

    post(url)

if __name__ == '__main__':
    main()



#!/usr/bin/env python
#coding:utf-8
from setuptools import setup, find_packages 

setup(
    name='42qucc',
    version="0.0.2",
    description= """
    A paste tool in CLI
        """,
    long_description="""
      the following is the usage:
      1.Paste file to 42qu.cc
        hi@Mars ~$ 42qucc < foo.txt            
        http://42qu.cc/xa47qt471        
      2.Custom url           
        hi@Mars ~$ 42qucc hi < foo.txt          
        http://42qu.cc/hi        
      3.Save web page to local file          
        hi@Mars ~$ 42qucc  http://42qu.cc/xa47qt471  >  foo.txt
    
    """,
    author="42qu.com 42区",
    author_email="admin@42qu.com",
    url="http://42qu.cc/:help",
    packages = ['cc42'],
    zip_safe=False,
    include_package_data=True,
    install_requires = [
        'requests>=0.13.3',
    ],
    entry_points = {
        'console_scripts': [
            '42qucc=cc42.cc42:main',
        ],
    },

)

if __name__ == "__main__":
    import sys
    if sys.getdefaultencoding() == 'ascii':
        reload(sys)
        sys.setdefaultencoding('utf-8')

